==> cfiles-v0.16.11.zip: cfiles/messages/sl/base.php <==
<?php

return [
    'Title' => 'Naslov',
    '%filename% has invalid extension and was skipped.' => '',
    '/ (root)' => '',
    '<strong>Confirm</strong> delete file' => '',
    '<strong>Create</strong> folder' => '',
    '<strong>Edit</strong> file' => '',
    '<strong>Edit</strong> folder' => '',
    '<strong>File</strong> download url' => '',
    '<strong>File</strong> url' => '',
    '<strong>File</strong> versions' => '',
    '<strong>Files</strong> module configuration' => '',
    '<strong>Folder</strong> url' => '',
    '<strong>Move</strong> files' => '',
    'A file with that name already exists in this folder.' => '',
    'Actions' => '',
    'Add directory' => '',
    'Add file(s)' => '',
    'Add files' => '',
    'Adds files module to this space.' => '',
    'Adds files module to your profile.' => '',
    'Allows the user to modify or delete any files.' => '',
    'Allows the user to upload new files and create folders' => '',
    'An error occurred while creating folder {folder}.' => '',
    'An error occurred while unpacking {filename}.' => '',
    'Archive %filename% could not be extracted.' => '',
    'Are you really sure to delete this version?' => '',
    'Author' => '',
    'Cannot edit non existing file.' => '',
    'Close' => '',
    'Could not find folder with id: %id%' => '',
    'Could not import file with guid {guid}. File not found' => '',
    'Could not move the item!' => '',
    'Creator' => '',
    'Delete' => '',
    'Delete this version!' => '',
    'Description' => '',
    'Destination folder not found!' => '',
    'Disable archive (ZIP) support' => '',
    'Display Url' => '',
    'Display a download count column' => '',
    'Do you really want to delete this {number} item(s) with all subcontent?' => '',
    'Download' => '',
    'Download ZIP' => '',
    'Downloads' => '',
    'Edit' => '',
    'Edit directory' => '',
    'File' => '',
    'File "{movedItemName}" has been moved into the folder "{targetFolderName}".' => '',
    'File (Module)' => '',
    'File content ID' => '',
    'File {fileName} has been reverted to version from {fileDateTime}' => '',
    'Files' => '',
    'Files (Module)' => '',
    'Files from the stream' => '',
    'Folder' => '',
    'Folder "{movedItemName}" has been moved into the folder "{targetFolderName}".' => '',
    'Folder ID' => '',
    'Folder content ID' => '',
    'Folder should not start or end with blank space.' => '',
    'Folder {name} can\'t be moved to itself!' => '',
    'Folder {name} given folder is not editable!' => '',
    'Folders' => '',
    'Hide in Stream' => '',
    'Import Zip' => '',
    'Is Public' => '',
    'Likes/Comments' => '',
    'Make Private' => '',
    'Make Public' => '',
    'Manage files' => '',
    'Move' => '',
    'Move to another Space' => '',
    'Moving to the same folder is not valid.' => '',
    'Moving to this folder is invalid.' => '',
    'Name' => '',
    'No file found!' => '',
    'Note: Changes of the folders visibility, will be inherited by all contained files and folders.' => '',
    'Open' => '',
    'Open file folder' => '',
    'Opening archive failed with error code %code%.' => '',
    'Parent Folder ID' => '',
    'Please select a valid destination folder for %title%.' => '',
    'Revert to this version' => '',
    'Root' => '',
    'Select what file version you want to switch.' => '',
    'Selected items...' => '',
    'Show Post' => '',
    'Show older versions' => '',
    'Size' => '',
    'Size: {size}' => '',
    'Some files could not be imported: ' => '',
    'Some files could not be moved: ' => '',
    'The root folder is the entry point that contains all available files.' => '',
    'The version "{versionDate}" could not be deleted!' => '',
    'The version "{versionDate}" has been deleted.' => '',
    'This file is only visible for you and your friends.' => '',
    'This file is private.' => '',
    'This file is protected.' => '',
    'This file is public.' => '',
    'This folder is empty.' => '',
    'This folder is only visible for you and your friends.' => '',
    'This folder is private.' => '',
    'This folder is protected.' => '',
    'This folder is public.' => '',
    'Time' => '',
    'Unfortunately you have no permission to upload/edit files.' => '',
    'Updated' => '',
    'Upload files or create a subfolder with the buttons on the top.' => '',
    'Upload files to the stream to fill this folder.' => '',
    'Versions' => '',
    'Wrong moved item!' => '',
    'Wrong target folder!' => '',
    'You can find all files that have been posted to this stream here.' => '',
    'You cannot move the file "{name}"!' => '',
    'You cannot move the folder "{name}"!' => '',
    'ZIP selected' => '',
    'ZIP support is not enabled.' => '',
];

==> cfiles-v0.17.1.zip: cfiles/messages/sl/base.php <==
<?php

return [
    'Actions' => 'Dejanja',
    'Close' => 'Zapri',
    'Delete' => 'Briši',
    'Download' => 'Prenos',
    'Edit' => 'Uredi',
    'Files' => 'Datoteke',
    'Open' => 'Odpri',
    'Title' => 'Naslov',
    '%filename% has invalid extension and was skipped.' => '',
    '/ (root)' => '',
    '<strong>Confirm</strong> delete file' => '',
    '<strong>Create</strong> folder' => '',
    '<strong>Edit</strong> file' => '',
    '<strong>Edit</strong> folder' => '',
    '<strong>File</strong> download url' => '',
    '<strong>File</strong> url' => '',
    '<strong>File</strong> versions' => '',
    '<strong>Files</strong> module configuration' => '',
    '<strong>Folder</strong> url' => '',
    '<strong>Move</strong> files' => '',
    'A file with that name already exists in this folder.' => '',
    'Add directory' => '',
    'Add file(s)' => '',
    'Add files' => '',
    'Adds files module to this space.' => '',
    'Adds files module to your profile.' => '',
    'Allows the user to modify or delete any files.' => '',
    'Allows the user to upload new files and create folders' => '',
    'An error occurred while creating folder {folder}.' => '',
    'An error occurred while unpacking {filename}.' => '',
    'Archive %filename% could not be extracted.' => '',
    'Are you really sure to delete this version?' => '',
    'Author' => '',
    'Cannot edit non existing file.' => '',
    'Could not find folder with id: %id%' => '',
    'Could not import file with guid {guid}. File not found' => '',
    'Could not move the item!' => '',
    'Creator' => '',
    'Delete this version!' => '',
    'Description' => '',
    'Destination folder not found!' => '',
    'Disable archive (ZIP) support' => '',
    'Display Url' => '',
    'Display a download count column' => '',
    'Do you really want to delete this {number} item(s) with all subcontent?' => '',
    'Download ZIP' => '',
    'Downloads' => '',
    'Edit directory' => '',
    'File' => '',
    'File "{movedItemName}" has been moved into the folder "{targetFolderName}".' => '',
    'File (Module)' => '',
    'File content ID' => '',
    'File {fileName} has been reverted to version from {fileDateTime}' => '',
    'Files (Module)' => '',
    'Files from the stream' => '',
    'Folder' => '',
    'Folder "{movedItemName}" has been moved into the folder "{targetFolderName}".' => '',
    'Folder ID' => '',
    'Folder content ID' => '',
    'Folder should not start or end with blank space.' => '',
    'Folder {name} can\'t be moved to itself!' => '',
    'Folder {name} given folder is not editable!' => '',
    'Folders' => '',
    'Hide in Stream' => '',
    'Import Zip' => '',
    'Is Public' => '',
    'Likes/Comments' => '',
    'Make Private' => '',
    'Make Public' => '',
    'Manage files' => '',
    'Move' => '',
    'Moving to the same folder is not valid.' => '',
    'Moving to this folder is invalid.' => '',
    'Name' => '',
    'No file found!' => '',
    'Note: Changes of the folders visibility, will be inherited by all contained files and folders.' => '',
    'Open file folder' => '',
    'Opening archive failed with error code %code%.' => '',
    'Parent Folder ID' => '',
    'Please select a valid destination folder for %title%.' => '',
    'Revert to this version' => '',
    'Root' => '',
    'Select what file version you want to switch.' => '',
    'Selected items...' => '',
    'Show Post' => '',
    'Show older versions' => '',
    'Size' => '',
    'Size: {size}' => '',
    'Some files could not be imported: ' => '',
    'Some files could not be moved: ' => '',
    'The root folder is the entry point that contains all available files.' => '',
    'The version "{versionDate}" could not be deleted!' => '',
    'The version "{versionDate}" has been deleted.' => '',
    'This file is only visible for you and your friends.' => '',
    'This file is private.' => '',
    'This file is protected.' => '',
    'This file is public.' => '',
    'This folder is empty.' => '',
    'This folder is only visible for you and your friends.' => '',
    'This folder is private.' => '',
    'This folder is protected.' => '',
    'This folder is public.' => '',
    'Time' => '',
    'Unfortunately you have no permission to upload/edit files.' => '',
    'Updated' => '',
    'Upload files or create a subfolder with the buttons on the top.' => '',
    'Upload files to the stream to fill this folder.' => '',
    'Versions' => '',
    'Wrong moved item!' => '',
    'Wrong target folder!' => '',
    'You can find all files that have been posted to this stream here.' => '',
    'You cannot move the file "{name}"!' => '',
    'You cannot move the folder "{name}"!' => '',
    'ZIP selected' => '',
    'ZIP support is not enabled.' => '',
];
